@@ -2,7 +2,8 @@ vblpcmfit<-function(variational.start, STEPS=30, maxiter=100, tol=1e-6, STRAT=1,
   {
   if (length(d_vector)!=9)
     stop("You must supply a d_vector of length 9. Please refer to the help file for vblpcmfit\n")
-  P<-variational.start$P
+  P_n<-variational.start$P_n
+  P_e<-variational.start$P_e
   model<-variational.start$model
   d<-variational.start$d
   N<-variational.start$N
@@ -18,9 +19,12 @@ vblpcmfit<-function(variational.start, STEPS=30, maxiter=100, tol=1e-6, STRAT=1,
   EnonE<-variational.start$EnonE
   diam<-variational.start$diam
   hopslist<-variational.start$hopslist
-  XX<-variational.start$XX
-  V_xi<-variational.start$V_xi
-  V_psi2<-variational.start$V_psi2
+  XX_n<-variational.start$XX_n
+  XX_e<-variational.start$XX_e
+  V_xi_n<-variational.start$V_xi_n
+  V_xi_e<-variational.start$V_xi_e
+  V_psi2_n<-variational.start$V_psi2_n
+  V_psi2_e<-variational.start$V_psi2_e
   V_z<-variational.start$V_z
   V_sigma2<-variational.start$V_sigma2
   V_eta<-variational.start$V_eta
@@ -36,14 +40,14 @@ vblpcmfit<-function(variational.start, STEPS=30, maxiter=100, tol=1e-6, STRAT=1,
   alpha<-variational.start$alpha
   inv_sigma02<-variational.start$inv_sigma02
   conv=0 # not converged to start with
-  out<-.C("Rf_VB_bbs", NAOK=TRUE, steps=as.integer(STEPS), max_iter=as.integer(maxiter), P=as.integer(P), 
-           D=as.integer(d), N=as.integer(N), NE=as.integer(NE), NnonE=as.integer(NnonE), NM=as.integer(NM),
+  out<-.C("Rf_VB_bbs", NAOK=TRUE, steps=as.integer(STEPS), max_iter=as.integer(maxiter), P_n=as.integer(P_n), 
+           P_e=as.integer(P_e), D=as.integer(d), N=as.integer(N), NE=as.integer(NE), NnonE=as.integer(NnonE), NM=as.integer(NM),
            G=as.integer(G), Y=as.numeric(t(Y)), E=as.integer(t(E)), nonE=as.integer(t(nonE)), M=as.integer(t(M)),
   	   numedges=as.integer(t(numedges)), EnonE=as.integer(t(EnonE)), diam=as.integer(diam),
-	   hopslist=as.integer(t(hopslist)), XX=as.double(t(XX)),
-           V_xi=as.double(V_xi), V_psi2=as.double(V_psi2), V_z=as.double(t(V_z)),
-           V_sigma2=as.double(V_sigma2), V_eta=as.double(t(V_eta)),
-           V_lambda=as.double(t(V_lambda)),
+	   hopslist=as.integer(t(hopslist)), XX_n=as.double(t(XX_n)), XX_e=as.double(t(XX_e)),
+           V_xi_n=as.double(t(V_xi_n)), V_xi_e=as.double(V_xi_e), V_psi2_n=as.double(V_psi2_n), 
+           V_psi2_e=as.double(V_psi2_e), V_z=as.double(t(V_z)), V_sigma2=as.double(V_sigma2), 
+           V_eta=as.double(t(V_eta)), V_lambda=as.double(t(V_lambda)),
            V_omega2=as.double(V_omega2), V_nu=as.double(V_nu), V_alpha=as.double(V_alpha),
            xi=as.double(xi), psi2=as.double(psi2), sigma02=as.double(sigma02),
            omega2=as.double(omega2), nu=as.double(nu), alpha=as.double(alpha),
@@ -51,7 +55,8 @@ vblpcmfit<-function(variational.start, STEPS=30, maxiter=100, tol=1e-6, STRAT=1,
 	   seed=as.double(seed), d_vector=as.double(d_vector), conv=as.integer(conv),
 	   PACKAGE="VBLPCM")
   
-  V_xi<-out$V_xi
+  V_xi_n<-out$V_xi_n
+  V_xi_e<-out$V_xi_e
   V_z<-t(matrix(out$V_z,ncol=N))
   V_sigma2<-out$V_sigma2
   V_eta<-t(matrix(out$V_eta,ncol=G))
@@ -59,14 +64,16 @@ vblpcmfit<-function(variational.start, STEPS=30, maxiter=100, tol=1e-6, STRAT=1,
   V_lambda<-t(matrix(out$V_lambda,ncol=G))
   V_nu<-out$V_nu
   V_alpha<-out$V_alpha
-  V_psi2<-out$V_psi2
+  V_psi2_n<-out$V_psi2_n
+  V_psi2_e<-out$V_psi2_e
   
   V_eta<-t(apply(V_eta, 1, "-", apply(V_z, 2, mean)))
   V_z<-t(apply(V_z, 1, "-", apply(V_z, 2, mean)))
   
   variational.params<-list()
   variational.params$net<-variational.start$net
-  P->variational.params$P
+  P_n->variational.params$P_n
+  P_e->variational.params$P_e
   model->variational.params$model
   d->variational.params$d
   N->variational.params$N
@@ -82,9 +89,12 @@ vblpcmfit<-function(variational.start, STEPS=30, maxiter=100, tol=1e-6, STRAT=1,
   EnonE->variational.params$EnonE
   diam->variational.params$diam
   hopslist->variational.params$hopslist
-  XX->variational.params$XX
-  V_xi->variational.params$V_xi
-  V_psi2->variational.params$V_psi2
+  XX_n->variational.params$XX_n
+  XX_e->variational.params$XX_e
+  V_xi_n->variational.params$V_xi_n
+  V_xi_e->variational.params$V_xi_e
+  V_psi2_n->variational.params$V_psi2_n
+  V_psi2_e->variational.params$V_psi2_e
   V_z->variational.params$V_z
   V_sigma2->variational.params$V_sigma2
   V_eta->variational.params$V_eta
